# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/admin/v0/mediator_initialization_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/admin/v0/mediator_initialization_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from ...api.v0 import sequencer_connection_pb2 as com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connection__pb2
from ....protocol.v0 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2
from ....protocol.v0 import topology_ext_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_topology__ext__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMcom/digitalasset/canton/domain/admin/v0/mediator_initialization_service.proto\x12\'com.digitalasset.canton.domain.admin.v0\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a@com/digitalasset/canton/domain/api/v0/sequencer_connection.proto\x1a\x34\x63om/digitalasset/canton/protocol/v0/sequencing.proto\x1a\x36\x63om/digitalasset/canton/protocol/v0/topology_ext.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xf9\x03\n\x19InitializeMediatorRequest\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12\x1f\n\x0bmediator_id\x18\x02 \x01(\tR\nmediatorId\x12o\n\x16\x63urrent_identity_state\x18\x03 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v0.TopologyTransactionsR\x14\x63urrentIdentityState\x12h\n\x11\x64omain_parameters\x18\x04 \x01(\x0b\x32;.com.digitalasset.canton.protocol.v0.StaticDomainParametersR\x10\x64omainParameters\x12m\n\x14sequencer_connection\x18\x05 \x01(\x0b\x32:.com.digitalasset.canton.domain.api.v0.SequencerConnectionR\x13sequencerConnection\x12T\n\x17signing_key_fingerprint\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x15signingKeyFingerprint\"\xfd\x02\n\x1aInitializeMediatorResponse\x12g\n\x07success\x18\x01 \x01(\x0b\x32K.com.digitalasset.canton.domain.admin.v0.InitializeMediatorResponse.SuccessH\x00R\x07success\x12g\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32K.com.digitalasset.canton.domain.admin.v0.InitializeMediatorResponse.FailureH\x00R\x07\x66\x61ilure\x1a\x61\n\x07Success\x12V\n\x0cmediator_key\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.crypto.v0.SigningPublicKeyR\x0bmediatorKey\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reasonB\x07\n\x05value2\xb7\x01\n\x1dMediatorInitializationService\x12\x95\x01\n\nInitialize\x12\x42.com.digitalasset.canton.domain.admin.v0.InitializeMediatorRequest\x1a\x43.com.digitalasset.canton.domain.admin.v0.InitializeMediatorResponseBXZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.admin.v0.mediator_initialization_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0'
  _globals['_INITIALIZEMEDIATORREQUEST']._serialized_start=379
  _globals['_INITIALIZEMEDIATORREQUEST']._serialized_end=884
  _globals['_INITIALIZEMEDIATORRESPONSE']._serialized_start=887
  _globals['_INITIALIZEMEDIATORRESPONSE']._serialized_end=1268
  _globals['_INITIALIZEMEDIATORRESPONSE_SUCCESS']._serialized_start=1127
  _globals['_INITIALIZEMEDIATORRESPONSE_SUCCESS']._serialized_end=1224
  _globals['_INITIALIZEMEDIATORRESPONSE_FAILURE']._serialized_start=1226
  _globals['_INITIALIZEMEDIATORRESPONSE_FAILURE']._serialized_end=1259
  _globals['_MEDIATORINITIALIZATIONSERVICE']._serialized_start=1271
  _globals['_MEDIATORINITIALIZATIONSERVICE']._serialized_end=1454
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/admin/v0/domain_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/admin/v0/domain_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from ....protocol.v0 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2
from ....protocol.v1 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_sequencing__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<com/digitalasset/canton/domain/admin/v0/domain_service.proto\x12\'com.digitalasset.canton.domain.admin.v0\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x34\x63om/digitalasset/canton/protocol/v0/sequencing.proto\x1a\x34\x63om/digitalasset/canton/protocol/v1/sequencing.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x83\x02\n\x13GetDomainParameters\x1a\t\n\x07Request\x1a\xe0\x01\n\x08Response\x12\x62\n\rparameters_v0\x18\x01 \x01(\x0b\x32;.com.digitalasset.canton.protocol.v0.StaticDomainParametersH\x00R\x0cparametersV0\x12\x62\n\rparameters_v1\x18\x02 \x01(\x0b\x32;.com.digitalasset.canton.protocol.v1.StaticDomainParametersH\x00R\x0cparametersV1B\x0c\n\nparameters\"\x84\x01\n\x1bServiceAgreementAcceptances\x12\x65\n\x0b\x61\x63\x63\x65ptances\x18\x01 \x03(\x0b\x32\x43.com.digitalasset.canton.domain.admin.v0.ServiceAgreementAcceptanceR\x0b\x61\x63\x63\x65ptances\"\xec\x01\n\x1aServiceAgreementAcceptance\x12!\n\x0c\x61greement_id\x18\x01 \x01(\tR\x0b\x61greementId\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantId\x12J\n\tsignature\x18\x03 \x01(\x0b\x32,.com.digitalasset.canton.crypto.v0.SignatureR\tsignature\x12\x38\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp2\xaa\x03\n\rDomainService\x12\x7f\n\x1fListServiceAgreementAcceptances\x12\x16.google.protobuf.Empty\x1a\x44.com.digitalasset.canton.domain.admin.v0.ServiceAgreementAcceptances\x12j\n\x13GetDomainParameters\x12\x16.google.protobuf.Empty\x1a;.com.digitalasset.canton.protocol.v0.StaticDomainParameters\x12\xab\x01\n\x1cGetDomainParametersVersioned\x12\x44.com.digitalasset.canton.domain.admin.v0.GetDomainParameters.Request\x1a\x45.com.digitalasset.canton.domain.admin.v0.GetDomainParameters.ResponseBXZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.admin.v0.domain_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0'
  _globals['_GETDOMAINPARAMETERS']._serialized_start=324
  _globals['_GETDOMAINPARAMETERS']._serialized_end=583
  _globals['_GETDOMAINPARAMETERS_REQUEST']._serialized_start=347
  _globals['_GETDOMAINPARAMETERS_REQUEST']._serialized_end=356
  _globals['_GETDOMAINPARAMETERS_RESPONSE']._serialized_start=359
  _globals['_GETDOMAINPARAMETERS_RESPONSE']._serialized_end=583
  _globals['_SERVICEAGREEMENTACCEPTANCES']._serialized_start=586
  _globals['_SERVICEAGREEMENTACCEPTANCES']._serialized_end=718
  _globals['_SERVICEAGREEMENTACCEPTANCE']._serialized_start=721
  _globals['_SERVICEAGREEMENTACCEPTANCE']._serialized_end=957
  _globals['_DOMAINSERVICE']._serialized_start=960
  _globals['_DOMAINSERVICE']._serialized_end=1386
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import io
from typing import Optional

from .. import dazl_go_module

__all__ = ["canton_proto_rewrite", "daml_proto_rewrite"]


def canton_proto_rewrite(short_name: str, input_file: str) -> str:
    with io.StringIO() as buf_out:
        for line in input_file.splitlines(keepends=True):
            rewrite_canton_proto_line(short_name, line, buf_out)
        return buf_out.getvalue()


def rewrite_canton_proto_line(short_name: str, line: str, buf_out: io.StringIO) -> None:
    s = line.strip()
    if s.startswith("None = "):
        # the gRPC Python code generator spits out invalid Python
        # code when fields are called None, so rename fields that
        # we encounter that are called None
        buf_out.write(line.replace("None", "None_"))

    elif s == 'import "com/digitalasset/canton/topology/admin/v0/topology_ext.proto";':
        # this import needs to be rewritten because we move this
        # file around in order to make its package name match
        buf_out.write('import "com/digitalasset/canton/protocol/v0/topology_ext.proto";\n')

    elif s == 'import "com/digitalasset/canton/time/admin/v0/domain_time_service.proto";':
        # this import needs to be rewritten because we move this
        # file around in order to make its package name match
        buf_out.write('import "com/digitalasset/canton/domain/api/v0/domain_time_service.proto";\n')

    elif "scalapb" in line:
        # scalapb imports must be ignored, because we don't have those proto files handy
        # (and they're not actually required for our own purposes anyway)
        pass

    else:
        # write all other lines as-is, but also look for the
        # package directive as a hint for where we write our
        # own things
        buf_out.write(line)
        if proto_pkg := parse_proto_package(line):
            if (
                short_name
                == "com/digitalasset/canton/domain/admin/v0/sequencer_initialization_service.proto"
            ):
                # avoid import cycles
                go_pkg = f"{dazl_go_module}/go/api/com/digitalasset/canton/domain/admin/v0/sequencerinitializationservice"
            elif short_name == "com/digitalasset/canton/time/v30/time_proof.proto":
                # avoid import cycles
                go_pkg = f"{dazl_go_module}/go/api/com/digitalasset/canton/protocol/v30"
            else:
                go_pkg = f"{dazl_go_module}/go/api/" + proto_pkg.replace(".", "/")

            buf_out.write(f'option go_package = "{go_pkg}";\n')


def daml_proto_rewrite(short_name: str, input_file: str) -> str:
    with io.StringIO() as buf_out:
        did_write_package = False

        for line in input_file.splitlines(keepends=True):
            buf_out.write(line)

            # prefer the java_package directive for inferring our own package location,
            # because that's correct for Daml-LF 1.16; but TraceContext in the Ledger API
            # doesn't define that, so fall back to the protobuf package
            if not did_write_package:
                suggested_pkg = parse_java_package(line)
                if suggested_pkg is None:
                    suggested_pkg = parse_proto_package(line)
                if suggested_pkg is not None:
                    go_pkg = (
                        "github.com/digital-asset/dazl-client/v8/go/api/"
                        + suggested_pkg.replace(".", "/")
                    )
                    buf_out.write(f'option go_package = "{go_pkg}";\n')
                    did_write_package = True
        return buf_out.getvalue()


def parse_proto_package(line: str) -> Optional[str]:
    if line.startswith("package "):
        _, _, proto_pkg = line.partition(" ")
        return proto_pkg.strip().replace(";", "")
    else:
        return None


def parse_java_package(line: str) -> Optional[str]:
    if line.startswith("option java_package = "):
        return line.partition('"')[2].rpartition('"')[0]
    else:
        return None



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v1/topology.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v1/topology.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from ..v0 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_topology__pb2
from . import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_sequencing__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2com/digitalasset/canton/protocol/v1/topology.proto\x12#com.digitalasset.canton.protocol.v1\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x32\x63om/digitalasset/canton/protocol/v0/topology.proto\x1a\x34\x63om/digitalasset/canton/protocol/v1/sequencing.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf4\x07\n\x13TopologyStateUpdate\x12S\n\toperation\x18\x01 \x01(\x0e\x32\x35.com.digitalasset.canton.protocol.v0.TopologyChangeOpR\toperation\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12m\n\x14namespace_delegation\x18\x03 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v0.NamespaceDelegationH\x00R\x13namespaceDelegation\x12p\n\x15identifier_delegation\x18\x04 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v0.IdentifierDelegationH\x00R\x14identifierDelegation\x12i\n\x14owner_to_key_mapping\x18\x05 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v0.OwnerToKeyMappingH\x00R\x11ownerToKeyMapping\x12k\n\x14party_to_participant\x18\x06 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v0.PartyToParticipantH\x00R\x12partyToParticipant\x12~\n\x1bsigned_legal_identity_claim\x18\x07 \x01(\x0b\x32=.com.digitalasset.canton.protocol.v0.SignedLegalIdentityClaimH\x00R\x18signedLegalIdentityClaim\x12\x64\n\x11participant_state\x18\x08 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v0.ParticipantStateH\x00R\x10participantState\x12^\n\x0fvetted_packages\x18\t \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v0.VettedPackagesH\x00R\x0evettedPackages\x12n\n\x15mediator_domain_state\x18\n \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v0.MediatorDomainStateH\x00R\x13mediatorDomainStateB\t\n\x07mapping\"\x9b\x01\n\x16\x44omainParametersChange\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12i\n\x11\x64omain_parameters\x18\x02 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v1.DynamicDomainParametersR\x10\x64omainParameters\"\xa1\x01\n\x1b\x44omainGovernanceTransaction\x12w\n\x18\x64omain_parameters_change\x18\x01 \x01(\x0b\x32;.com.digitalasset.canton.protocol.v1.DomainParametersChangeH\x00R\x16\x64omainParametersChangeB\t\n\x07mapping\"\xf4\x01\n\x13TopologyTransaction\x12]\n\x0cstate_update\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v1.TopologyStateUpdateH\x00R\x0bstateUpdate\x12o\n\x11\x64omain_governance\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.protocol.v1.DomainGovernanceTransactionH\x00R\x10\x64omainGovernanceB\r\n\x0btransaction\"\x8f\x04\n#RegisterTopologyTransactionResponse\x12!\n\x0crequested_by\x18\x01 \x01(\tR\x0brequestedBy\x12 \n\x0bparticipant\x18\x02 \x01(\tR\x0bparticipant\x12\x1d\n\nrequest_id\x18\x03 \x01(\tR\trequestId\x12i\n\x07results\x18\x04 \x03(\x0b\x32O.com.digitalasset.canton.protocol.v1.RegisterTopologyTransactionResponse.ResultR\x07results\x12\x1b\n\tdomain_id\x18\x05 \x01(\tR\x08\x64omainId\x1a\xfb\x01\n\x06Result\x12k\n\x05state\x18\x01 \x01(\x0e\x32U.com.digitalasset.canton.protocol.v1.RegisterTopologyTransactionResponse.Result.StateR\x05state\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"_\n\x05State\x12\x11\n\rMISSING_STATE\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x02\x12\x0c\n\x08REJECTED\x10\x03\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x04\x12\r\n\tDUPLICATE\x10\x05\x12\x0c\n\x08OBSOLETE\x10\x06\"\xfb\x01\n DomainTopologyTransactionMessage\x12J\n\tsignature\x18\x01 \x01(\x0b\x32,.com.digitalasset.canton.crypto.v0.SignatureR\tsignature\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12J\n\x13not_sequenced_after\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11notSequencedAfter\x12\"\n\x0ctransactions\x18\x04 \x03(\x0cR\x0ctransactionsBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v1.topology_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1'
  _globals['_TOPOLOGYSTATEUPDATE']._serialized_start=279
  _globals['_TOPOLOGYSTATEUPDATE']._serialized_end=1291
  _globals['_DOMAINPARAMETERSCHANGE']._serialized_start=1294
  _globals['_DOMAINPARAMETERSCHANGE']._serialized_end=1449
  _globals['_DOMAINGOVERNANCETRANSACTION']._serialized_start=1452
  _globals['_DOMAINGOVERNANCETRANSACTION']._serialized_end=1613
  _globals['_TOPOLOGYTRANSACTION']._serialized_start=1616
  _globals['_TOPOLOGYTRANSACTION']._serialized_end=1860
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE']._serialized_start=1863
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE']._serialized_end=2390
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE_RESULT']._serialized_start=2139
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE_RESULT']._serialized_end=2390
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE_RESULT_STATE']._serialized_start=2295
  _globals['_REGISTERTOPOLOGYTRANSACTIONRESPONSE_RESULT_STATE']._serialized_end=2390
  _globals['_DOMAINTOPOLOGYTRANSACTIONMESSAGE']._serialized_start=2393
  _globals['_DOMAINTOPOLOGYTRANSACTIONMESSAGE']._serialized_end=2644
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .topology_manager_read_service_pb2 import ExportTopologySnapshotRequest, ExportTopologySnapshotResponse, GenesisStateRequest, GenesisStateResponse, ListAllRequest, ListAllResponse, ListAuthorityOfRequest, ListAuthorityOfResponse, ListAvailableStoresRequest, ListAvailableStoresResponse, ListDecentralizedNamespaceDefinitionRequest, ListDecentralizedNamespaceDefinitionResponse, ListDomainParametersStateRequest, ListDomainParametersStateResponse, ListDomainTrustCertificateRequest, ListDomainTrustCertificateResponse, ListIdentifierDelegationRequest, ListIdentifierDelegationResponse, ListMediatorDomainStateRequest, ListMediatorDomainStateResponse, ListNamespaceDelegationRequest, ListNamespaceDelegationResponse, ListOwnerToKeyMappingRequest, ListOwnerToKeyMappingResponse, ListParticipantDomainPermissionRequest, ListParticipantDomainPermissionResponse, ListPartyHostingLimitsRequest, ListPartyHostingLimitsResponse, ListPartyToKeyMappingRequest, ListPartyToKeyMappingResponse, ListPartyToParticipantRequest, ListPartyToParticipantResponse, ListPurgeTopologyTransactionRequest, ListPurgeTopologyTransactionResponse, ListSequencerDomainStateRequest, ListSequencerDomainStateResponse, ListVettedPackagesRequest, ListVettedPackagesResponse

__all__ = [
    "TopologyManagerReadServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class TopologyManagerReadServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _TopologyManagerReadServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _TopologyManagerReadServiceAsyncStub: ...  # type: ignore
    def ListNamespaceDelegation(self, __1: ListNamespaceDelegationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListNamespaceDelegationResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListNamespaceDelegationResponse]]: ...
    def ListDecentralizedNamespaceDefinition(self, __1: ListDecentralizedNamespaceDefinitionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListDecentralizedNamespaceDefinitionResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListDecentralizedNamespaceDefinitionResponse]]: ...
    def ListIdentifierDelegation(self, __1: ListIdentifierDelegationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListIdentifierDelegationResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListIdentifierDelegationResponse]]: ...
    def ListOwnerToKeyMapping(self, __1: ListOwnerToKeyMappingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListOwnerToKeyMappingResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListOwnerToKeyMappingResponse]]: ...
    def ListPartyToKeyMapping(self, __1: ListPartyToKeyMappingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListPartyToKeyMappingResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyToKeyMappingResponse]]: ...
    def ListDomainTrustCertificate(self, __1: ListDomainTrustCertificateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListDomainTrustCertificateResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListDomainTrustCertificateResponse]]: ...
    def ListParticipantDomainPermission(self, __1: ListParticipantDomainPermissionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListParticipantDomainPermissionResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListParticipantDomainPermissionResponse]]: ...
    def ListPartyHostingLimits(self, __1: ListPartyHostingLimitsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListPartyHostingLimitsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyHostingLimitsResponse]]: ...
    def ListVettedPackages(self, __1: ListVettedPackagesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListVettedPackagesResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListVettedPackagesResponse]]: ...
    def ListPartyToParticipant(self, __1: ListPartyToParticipantRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListPartyToParticipantResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyToParticipantResponse]]: ...
    def ListAuthorityOf(self, __1: ListAuthorityOfRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListAuthorityOfResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListAuthorityOfResponse]]: ...
    def ListDomainParametersState(self, __1: ListDomainParametersStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListDomainParametersStateResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListDomainParametersStateResponse]]: ...
    def ListMediatorDomainState(self, __1: ListMediatorDomainStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListMediatorDomainStateResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListMediatorDomainStateResponse]]: ...
    def ListSequencerDomainState(self, __1: ListSequencerDomainStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListSequencerDomainStateResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListSequencerDomainStateResponse]]: ...
    def ListPurgeTopologyTransaction(self, __1: ListPurgeTopologyTransactionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListPurgeTopologyTransactionResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListPurgeTopologyTransactionResponse]]: ...
    def ListAvailableStores(self, __1: ListAvailableStoresRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListAvailableStoresResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListAvailableStoresResponse]]: ...
    def ListAll(self, __1: ListAllRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListAllResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListAllResponse]]: ...
    def ExportTopologySnapshot(self, __1: ExportTopologySnapshotRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ExportTopologySnapshotResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ExportTopologySnapshotResponse]]: ...
    def GenesisState(self, __1: GenesisStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[GenesisStateResponse], _grpc_aio.UnaryStreamCall[_typing.Any, GenesisStateResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyManagerReadServiceBlockingStub(TopologyManagerReadServiceStub):
    def ListNamespaceDelegation(self, __1: ListNamespaceDelegationRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListNamespaceDelegationResponse: ...
    def ListDecentralizedNamespaceDefinition(self, __1: ListDecentralizedNamespaceDefinitionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListDecentralizedNamespaceDefinitionResponse: ...
    def ListIdentifierDelegation(self, __1: ListIdentifierDelegationRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListIdentifierDelegationResponse: ...
    def ListOwnerToKeyMapping(self, __1: ListOwnerToKeyMappingRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListOwnerToKeyMappingResponse: ...
    def ListPartyToKeyMapping(self, __1: ListPartyToKeyMappingRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyToKeyMappingResponse: ...
    def ListDomainTrustCertificate(self, __1: ListDomainTrustCertificateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListDomainTrustCertificateResponse: ...
    def ListParticipantDomainPermission(self, __1: ListParticipantDomainPermissionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListParticipantDomainPermissionResponse: ...
    def ListPartyHostingLimits(self, __1: ListPartyHostingLimitsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyHostingLimitsResponse: ...
    def ListVettedPackages(self, __1: ListVettedPackagesRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListVettedPackagesResponse: ...
    def ListPartyToParticipant(self, __1: ListPartyToParticipantRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyToParticipantResponse: ...
    def ListAuthorityOf(self, __1: ListAuthorityOfRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAuthorityOfResponse: ...
    def ListDomainParametersState(self, __1: ListDomainParametersStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListDomainParametersStateResponse: ...
    def ListMediatorDomainState(self, __1: ListMediatorDomainStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListMediatorDomainStateResponse: ...
    def ListSequencerDomainState(self, __1: ListSequencerDomainStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSequencerDomainStateResponse: ...
    def ListPurgeTopologyTransaction(self, __1: ListPurgeTopologyTransactionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPurgeTopologyTransactionResponse: ...
    def ListAvailableStores(self, __1: ListAvailableStoresRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAvailableStoresResponse: ...
    def ListAll(self, __1: ListAllRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAllResponse: ...
    def ExportTopologySnapshot(self, __1: ExportTopologySnapshotRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ExportTopologySnapshotResponse: ...
    def GenesisState(self, __1: GenesisStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[GenesisStateResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyManagerReadServiceAsyncStub(TopologyManagerReadServiceStub):
    def ListNamespaceDelegation(self, __1: ListNamespaceDelegationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListNamespaceDelegationResponse]: ...  # type: ignore
    def ListDecentralizedNamespaceDefinition(self, __1: ListDecentralizedNamespaceDefinitionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListDecentralizedNamespaceDefinitionResponse]: ...  # type: ignore
    def ListIdentifierDelegation(self, __1: ListIdentifierDelegationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListIdentifierDelegationResponse]: ...  # type: ignore
    def ListOwnerToKeyMapping(self, __1: ListOwnerToKeyMappingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListOwnerToKeyMappingResponse]: ...  # type: ignore
    def ListPartyToKeyMapping(self, __1: ListPartyToKeyMappingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyToKeyMappingResponse]: ...  # type: ignore
    def ListDomainTrustCertificate(self, __1: ListDomainTrustCertificateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListDomainTrustCertificateResponse]: ...  # type: ignore
    def ListParticipantDomainPermission(self, __1: ListParticipantDomainPermissionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListParticipantDomainPermissionResponse]: ...  # type: ignore
    def ListPartyHostingLimits(self, __1: ListPartyHostingLimitsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyHostingLimitsResponse]: ...  # type: ignore
    def ListVettedPackages(self, __1: ListVettedPackagesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListVettedPackagesResponse]: ...  # type: ignore
    def ListPartyToParticipant(self, __1: ListPartyToParticipantRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyToParticipantResponse]: ...  # type: ignore
    def ListAuthorityOf(self, __1: ListAuthorityOfRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListAuthorityOfResponse]: ...  # type: ignore
    def ListDomainParametersState(self, __1: ListDomainParametersStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListDomainParametersStateResponse]: ...  # type: ignore
    def ListMediatorDomainState(self, __1: ListMediatorDomainStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListMediatorDomainStateResponse]: ...  # type: ignore
    def ListSequencerDomainState(self, __1: ListSequencerDomainStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListSequencerDomainStateResponse]: ...  # type: ignore
    def ListPurgeTopologyTransaction(self, __1: ListPurgeTopologyTransactionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPurgeTopologyTransactionResponse]: ...  # type: ignore
    def ListAvailableStores(self, __1: ListAvailableStoresRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListAvailableStoresResponse]: ...  # type: ignore
    def ListAll(self, __1: ListAllRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListAllResponse]: ...  # type: ignore
    def ExportTopologySnapshot(self, __1: ExportTopologySnapshotRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ExportTopologySnapshotResponse]: ...  # type: ignore
    def GenesisState(self, __1: GenesisStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, GenesisStateResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

"""
This module contains the logic for how Protobuf files are renamed.
"""

from __future__ import annotations

from typing import Collection, Mapping, Optional, Set


def canton_proto_files(zip_file_names: Collection[str]) -> Mapping[str, str]:
    """
    Return paths to Canton protobuf/gRPC files that are interesting for code generation.
    The key is the "short" file path (starting with com/digitalasset) and the value is
    the full file path as it exists in the Canton .zip file distribution.
    """
    file_names = {}
    for name in zip_file_names:
        components = name.split("/")
        short_name = "/".join(name.split("/")[3:])

        if short_name == "com/digitalasset/canton/topology/admin/v0/topology_ext.proto":
            # this file has a different package name from its file location for historical
            # reasons, but leaving it like this breaks Python codegen because it has
            # an expectation that these lines match
            file_names["com/digitalasset/canton/protocol/v0/topology_ext.proto"] = name

        elif short_name == "com/digitalasset/canton/time/admin/v0/domain_time_service.proto":
            file_names["com/digitalasset/canton/domain/api/v0/domain_time_service.proto"] = name

        elif short_name == "com/digitalasset/canton/protocol/v0/versioned-google-rpc-status.proto":
            file_names["com/digitalasset/canton/protocol/v0/versioned_google_rpc_status.proto"] = (
                name
            )

        elif (
            components[1] == "protobuf"
            and components[-1].endswith(".proto")
            and not name.endswith("package.proto")
        ):
            # grab everything in the */protobuf directory that is a Protobuf file except
            # for the package.proto files, since those are just configuration for
            # Scala code generation, and that doesn't apply here
            file_names[short_name] = name
    return file_names


def daml_proto_files(zip_file_names: Collection[str], ledger_api_version: str) -> Mapping[str, str]:
    """
    Return paths to Daml protobuf/gRPC files that are interesting for code generation.
    The key is the "short" file path (starting with com/daml) and the value is
    the full file path as it exists in the Canton .zip file distribution.

    :param zip_file_names:
        The names of files inside the Daml protobuf distribution.

    :param ledger_api_version:
        The Ledger API version.
    """
    file_names = {}

    daml_lf_dir = detect_daml_lf_dir(zip_file_names)
    if daml_lf_dir is None:
        print(zip_file_names)
        raise ValueError("could not detect daml_lf_dir")
    for name in zip_file_names:
        short_name = "/".join(name.split("/")[1:])

        if short_name.startswith(
            f"com/daml/ledger/api/{ledger_api_version}/"
        ) and short_name.endswith(".proto"):
            # Ledger API protos
            file_names[short_name] = name
        elif short_name.startswith(daml_lf_dir) and short_name.endswith(".proto"):
            # Daml-LF protos
            file_names[short_name] = name

    return file_names


def detect_daml_lf_dir(paths: Collection[str]) -> Optional[str]:
    """
    Find the biggest Daml-LF v1 version in the set of file names from a Protobuf archive, and return
    the path that contains the associated files (with a trailing slash).

    This code will need to be revisited with Daml-LF 2 is stable.

    :param paths: The paths in a Protobuf zipfile to examine.
    :return: The root directory of a target Daml-LF protobuf version, stripped of a prefix.

    >>> detect_daml_lf_dir([
    ...    "protos-1.15.0/com/daml/daml_lf_1_10/something.proto",
    ...    "protos-1.15.0/com/daml/daml_lf_1_9/something.proto",
    ...    "protos-1.15.0/com/daml/daml_lf_dev/something.proto",
    ...    "protos-1.15.0/com/daml/daml_lf_1_what/something.proto",
    ... ])
    'com/daml/daml_lf_1_10/'
    """
    daml_lf_prefixes = ("com/daml/daml_lf_1_", "com/daml/daml_lf_2_")

    for daml_lf_prefix in daml_lf_prefixes:
        minor_versions = set()  # type: Set[int]
        for p in paths:
            _, _, truncated_path = p.partition("/")

            if truncated_path.startswith(daml_lf_prefix):
                version_str, _, _ = truncated_path[len(daml_lf_prefix) :].partition("/")
                try:
                    minor_versions.add(int(version_str))
                except ValueError:
                    # skip over unrecognized directory names
                    pass
        if minor_versions:
            return f"{daml_lf_prefix}{max(minor_versions)}/"
    else:
        return None



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CommandDeduplicationType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ASYNC_ONLY: _ClassVar[CommandDeduplicationType]
    ASYNC_AND_CONCURRENT_SYNC: _ClassVar[CommandDeduplicationType]
ASYNC_ONLY: CommandDeduplicationType
ASYNC_AND_CONCURRENT_SYNC: CommandDeduplicationType

class ExperimentalFeatures(_message.Message):
    __slots__ = ("self_service_error_codes", "static_time", "command_deduplication", "optional_ledger_id", "contract_ids", "committer_event_log", "explicit_disclosure", "user_and_party_local_metadata_extensions", "acs_active_at_offset", "template_filters", "command_inspection_service", "pruned_offsets")
    SELF_SERVICE_ERROR_CODES_FIELD_NUMBER: _ClassVar[int]
    STATIC_TIME_FIELD_NUMBER: _ClassVar[int]
    COMMAND_DEDUPLICATION_FIELD_NUMBER: _ClassVar[int]
    OPTIONAL_LEDGER_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_IDS_FIELD_NUMBER: _ClassVar[int]
    COMMITTER_EVENT_LOG_FIELD_NUMBER: _ClassVar[int]
    EXPLICIT_DISCLOSURE_FIELD_NUMBER: _ClassVar[int]
    USER_AND_PARTY_LOCAL_METADATA_EXTENSIONS_FIELD_NUMBER: _ClassVar[int]
    ACS_ACTIVE_AT_OFFSET_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_FILTERS_FIELD_NUMBER: _ClassVar[int]
    COMMAND_INSPECTION_SERVICE_FIELD_NUMBER: _ClassVar[int]
    PRUNED_OFFSETS_FIELD_NUMBER: _ClassVar[int]
    self_service_error_codes: ExperimentalSelfServiceErrorCodes
    static_time: ExperimentalStaticTime
    command_deduplication: CommandDeduplicationFeatures
    optional_ledger_id: ExperimentalOptionalLedgerId
    contract_ids: ExperimentalContractIds
    committer_event_log: ExperimentalCommitterEventLog
    explicit_disclosure: ExperimentalExplicitDisclosure
    user_and_party_local_metadata_extensions: ExperimentalUserAndPartyLocalMetadataExtensions
    acs_active_at_offset: AcsActiveAtOffsetFeature
    template_filters: TransactionsWithTemplateFilters
    command_inspection_service: ExperimentalCommandInspectionService
    pruned_offsets: StreamingPrunedOffsets
    def __init__(self, self_service_error_codes: _Optional[_Union[ExperimentalSelfServiceErrorCodes, _Mapping]] = ..., static_time: _Optional[_Union[ExperimentalStaticTime, _Mapping]] = ..., command_deduplication: _Optional[_Union[CommandDeduplicationFeatures, _Mapping]] = ..., optional_ledger_id: _Optional[_Union[ExperimentalOptionalLedgerId, _Mapping]] = ..., contract_ids: _Optional[_Union[ExperimentalContractIds, _Mapping]] = ..., committer_event_log: _Optional[_Union[ExperimentalCommitterEventLog, _Mapping]] = ..., explicit_disclosure: _Optional[_Union[ExperimentalExplicitDisclosure, _Mapping]] = ..., user_and_party_local_metadata_extensions: _Optional[_Union[ExperimentalUserAndPartyLocalMetadataExtensions, _Mapping]] = ..., acs_active_at_offset: _Optional[_Union[AcsActiveAtOffsetFeature, _Mapping]] = ..., template_filters: _Optional[_Union[TransactionsWithTemplateFilters, _Mapping]] = ..., command_inspection_service: _Optional[_Union[ExperimentalCommandInspectionService, _Mapping]] = ..., pruned_offsets: _Optional[_Union[StreamingPrunedOffsets, _Mapping]] = ...) -> None: ...

class ExperimentalSelfServiceErrorCodes(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ExperimentalStaticTime(_message.Message):
    __slots__ = ("supported",)
    SUPPORTED_FIELD_NUMBER: _ClassVar[int]
    supported: bool
    def __init__(self, supported: bool = ...) -> None: ...

class CommandDeduplicationFeatures(_message.Message):
    __slots__ = ("deduplication_period_support", "deduplication_type", "max_deduplication_duration_enforced")
    DEDUPLICATION_PERIOD_SUPPORT_FIELD_NUMBER: _ClassVar[int]
    DEDUPLICATION_TYPE_FIELD_NUMBER: _ClassVar[int]
    MAX_DEDUPLICATION_DURATION_ENFORCED_FIELD_NUMBER: _ClassVar[int]
    deduplication_period_support: CommandDeduplicationPeriodSupport
    deduplication_type: CommandDeduplicationType
    max_deduplication_duration_enforced: bool
    def __init__(self, deduplication_period_support: _Optional[_Union[CommandDeduplicationPeriodSupport, _Mapping]] = ..., deduplication_type: _Optional[_Union[CommandDeduplicationType, str]] = ..., max_deduplication_duration_enforced: bool = ...) -> None: ...

class ExperimentalOptionalLedgerId(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CommandDeduplicationPeriodSupport(_message.Message):
    __slots__ = ("offset_support", "duration_support")
    class OffsetSupport(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        OFFSET_NOT_SUPPORTED: _ClassVar[CommandDeduplicationPeriodSupport.OffsetSupport]
        OFFSET_NATIVE_SUPPORT: _ClassVar[CommandDeduplicationPeriodSupport.OffsetSupport]
        OFFSET_CONVERT_TO_DURATION: _ClassVar[CommandDeduplicationPeriodSupport.OffsetSupport]
    OFFSET_NOT_SUPPORTED: CommandDeduplicationPeriodSupport.OffsetSupport
    OFFSET_NATIVE_SUPPORT: CommandDeduplicationPeriodSupport.OffsetSupport
    OFFSET_CONVERT_TO_DURATION: CommandDeduplicationPeriodSupport.OffsetSupport
    class DurationSupport(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DURATION_NATIVE_SUPPORT: _ClassVar[CommandDeduplicationPeriodSupport.DurationSupport]
        DURATION_CONVERT_TO_OFFSET: _ClassVar[CommandDeduplicationPeriodSupport.DurationSupport]
    DURATION_NATIVE_SUPPORT: CommandDeduplicationPeriodSupport.DurationSupport
    DURATION_CONVERT_TO_OFFSET: CommandDeduplicationPeriodSupport.DurationSupport
    OFFSET_SUPPORT_FIELD_NUMBER: _ClassVar[int]
    DURATION_SUPPORT_FIELD_NUMBER: _ClassVar[int]
    offset_support: CommandDeduplicationPeriodSupport.OffsetSupport
    duration_support: CommandDeduplicationPeriodSupport.DurationSupport
    def __init__(self, offset_support: _Optional[_Union[CommandDeduplicationPeriodSupport.OffsetSupport, str]] = ..., duration_support: _Optional[_Union[CommandDeduplicationPeriodSupport.DurationSupport, str]] = ...) -> None: ...

class ExperimentalContractIds(_message.Message):
    __slots__ = ("v1",)
    class ContractIdV1Support(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        SUFFIXED: _ClassVar[ExperimentalContractIds.ContractIdV1Support]
        NON_SUFFIXED: _ClassVar[ExperimentalContractIds.ContractIdV1Support]
    SUFFIXED: ExperimentalContractIds.ContractIdV1Support
    NON_SUFFIXED: ExperimentalContractIds.ContractIdV1Support
    V1_FIELD_NUMBER: _ClassVar[int]
    v1: ExperimentalContractIds.ContractIdV1Support
    def __init__(self, v1: _Optional[_Union[ExperimentalContractIds.ContractIdV1Support, str]] = ...) -> None: ...

class ExperimentalCommitterEventLog(_message.Message):
    __slots__ = ("event_log_type",)
    class CommitterEventLogType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        CENTRALIZED: _ClassVar[ExperimentalCommitterEventLog.CommitterEventLogType]
        DISTRIBUTED: _ClassVar[ExperimentalCommitterEventLog.CommitterEventLogType]
    CENTRALIZED: ExperimentalCommitterEventLog.CommitterEventLogType
    DISTRIBUTED: ExperimentalCommitterEventLog.CommitterEventLogType
    EVENT_LOG_TYPE_FIELD_NUMBER: _ClassVar[int]
    event_log_type: ExperimentalCommitterEventLog.CommitterEventLogType
    def __init__(self, event_log_type: _Optional[_Union[ExperimentalCommitterEventLog.CommitterEventLogType, str]] = ...) -> None: ...

class ExperimentalExplicitDisclosure(_message.Message):
    __slots__ = ("supported",)
    SUPPORTED_FIELD_NUMBER: _ClassVar[int]
    supported: bool
    def __init__(self, supported: bool = ...) -> None: ...

class ExperimentalUserAndPartyLocalMetadataExtensions(_message.Message):
    __slots__ = ("supported",)
    SUPPORTED_FIELD_NUMBER: _ClassVar[int]
    supported: bool
    def __init__(self, supported: bool = ...) -> None: ...

class AcsActiveAtOffsetFeature(_message.Message):
    __slots__ = ("supported",)
    SUPPORTED_FIELD_NUMBER: _ClassVar[int]
    supported: bool
    def __init__(self, supported: bool = ...) -> None: ...

class TransactionsWithTemplateFilters(_message.Message):
    __slots__ = ("supported",)
    SUPPORTED_FIELD_NUMBER: _ClassVar[int]
    supported: bool
    def __init__(self, supported: bool = ...) -> None: ...

class ExperimentalCommandInspectionService(_message.Message):
    __slots__ = ("supported",)
    SUPPORTED_FIELD_NUMBER: _ClassVar[int]
    supported: bool
    def __init__(self, supported: bool = ...) -> None: ...

class StreamingPrunedOffsets(_message.Message):
    __slots__ = ("supported",)
    SUPPORTED_FIELD_NUMBER: _ClassVar[int]
    supported: bool
    def __init__(self, supported: bool = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class StoredParties(_message.Message):
    __slots__ = ("parties",)
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    parties: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, parties: _Optional[_Iterable[str]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....crypto.v0 import crypto_pb2 as _crypto_pb2
from ....protocol.v0 import topology_pb2 as _topology_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListPartiesRequest(_message.Message):
    __slots__ = ("as_of", "limit", "filter_domain", "filter_party", "filter_participant")
    AS_OF_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    FILTER_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    FILTER_PARTY_FIELD_NUMBER: _ClassVar[int]
    FILTER_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    as_of: _timestamp_pb2.Timestamp
    limit: int
    filter_domain: str
    filter_party: str
    filter_participant: str
    def __init__(self, as_of: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., limit: _Optional[int] = ..., filter_domain: _Optional[str] = ..., filter_party: _Optional[str] = ..., filter_participant: _Optional[str] = ...) -> None: ...

class ListPartiesResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("party", "participants")
        class ParticipantDomains(_message.Message):
            __slots__ = ("participant", "domains")
            class DomainPermissions(_message.Message):
                __slots__ = ("domain", "permission")
                DOMAIN_FIELD_NUMBER: _ClassVar[int]
                PERMISSION_FIELD_NUMBER: _ClassVar[int]
                domain: str
                permission: _topology_pb2.ParticipantPermission
                def __init__(self, domain: _Optional[str] = ..., permission: _Optional[_Union[_topology_pb2.ParticipantPermission, str]] = ...) -> None: ...
            PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
            DOMAINS_FIELD_NUMBER: _ClassVar[int]
            participant: str
            domains: _containers.RepeatedCompositeFieldContainer[ListPartiesResponse.Result.ParticipantDomains.DomainPermissions]
            def __init__(self, participant: _Optional[str] = ..., domains: _Optional[_Iterable[_Union[ListPartiesResponse.Result.ParticipantDomains.DomainPermissions, _Mapping]]] = ...) -> None: ...
        PARTY_FIELD_NUMBER: _ClassVar[int]
        PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
        party: str
        participants: _containers.RepeatedCompositeFieldContainer[ListPartiesResponse.Result.ParticipantDomains]
        def __init__(self, party: _Optional[str] = ..., participants: _Optional[_Iterable[_Union[ListPartiesResponse.Result.ParticipantDomains, _Mapping]]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListPartiesResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListPartiesResponse.Result, _Mapping]]] = ...) -> None: ...

class ListKeyOwnersRequest(_message.Message):
    __slots__ = ("as_of", "limit", "filter_domain", "filter_key_owner_type", "filter_key_owner_uid")
    AS_OF_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    FILTER_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    FILTER_KEY_OWNER_TYPE_FIELD_NUMBER: _ClassVar[int]
    FILTER_KEY_OWNER_UID_FIELD_NUMBER: _ClassVar[int]
    as_of: _timestamp_pb2.Timestamp
    limit: int
    filter_domain: str
    filter_key_owner_type: str
    filter_key_owner_uid: str
    def __init__(self, as_of: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., limit: _Optional[int] = ..., filter_domain: _Optional[str] = ..., filter_key_owner_type: _Optional[str] = ..., filter_key_owner_uid: _Optional[str] = ...) -> None: ...

class ListKeyOwnersResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("domain", "key_owner", "signing_keys", "encryption_keys")
        DOMAIN_FIELD_NUMBER: _ClassVar[int]
        KEY_OWNER_FIELD_NUMBER: _ClassVar[int]
        SIGNING_KEYS_FIELD_NUMBER: _ClassVar[int]
        ENCRYPTION_KEYS_FIELD_NUMBER: _ClassVar[int]
        domain: str
        key_owner: str
        signing_keys: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.SigningPublicKey]
        encryption_keys: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.EncryptionPublicKey]
        def __init__(self, domain: _Optional[str] = ..., key_owner: _Optional[str] = ..., signing_keys: _Optional[_Iterable[_Union[_crypto_pb2.SigningPublicKey, _Mapping]]] = ..., encryption_keys: _Optional[_Iterable[_Union[_crypto_pb2.EncryptionPublicKey, _Mapping]]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListKeyOwnersResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListKeyOwnersResponse.Result, _Mapping]]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Value(_message.Message):
    __slots__ = ("unit", "bool", "int64", "date", "timestamp", "numeric", "party", "text", "contract_id", "optional", "list", "text_map", "gen_map", "record", "variant", "enum")
    UNIT_FIELD_NUMBER: _ClassVar[int]
    BOOL_FIELD_NUMBER: _ClassVar[int]
    INT64_FIELD_NUMBER: _ClassVar[int]
    DATE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    NUMERIC_FIELD_NUMBER: _ClassVar[int]
    PARTY_FIELD_NUMBER: _ClassVar[int]
    TEXT_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    OPTIONAL_FIELD_NUMBER: _ClassVar[int]
    LIST_FIELD_NUMBER: _ClassVar[int]
    TEXT_MAP_FIELD_NUMBER: _ClassVar[int]
    GEN_MAP_FIELD_NUMBER: _ClassVar[int]
    RECORD_FIELD_NUMBER: _ClassVar[int]
    VARIANT_FIELD_NUMBER: _ClassVar[int]
    ENUM_FIELD_NUMBER: _ClassVar[int]
    unit: _empty_pb2.Empty
    bool: bool  # type: ignore
    int64: int
    date: int
    timestamp: int
    numeric: str
    party: str
    text: str
    contract_id: str
    optional: Optional
    list: List
    text_map: TextMap
    gen_map: GenMap
    record: Record
    variant: Variant
    enum: Enum
    def __init__(self, unit: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., bool: bool = ..., int64: _Optional[int] = ..., date: _Optional[int] = ..., timestamp: _Optional[int] = ..., numeric: _Optional[str] = ..., party: _Optional[str] = ..., text: _Optional[str] = ..., contract_id: _Optional[str] = ..., optional: _Optional[_Union[Optional, _Mapping]] = ..., list: _Optional[_Union[List, _Mapping]] = ..., text_map: _Optional[_Union[TextMap, _Mapping]] = ..., gen_map: _Optional[_Union[GenMap, _Mapping]] = ..., record: _Optional[_Union[Record, _Mapping]] = ..., variant: _Optional[_Union[Variant, _Mapping]] = ..., enum: _Optional[_Union[Enum, _Mapping]] = ...) -> None: ...  # type: ignore

class Record(_message.Message):
    __slots__ = ("record_id", "fields")
    RECORD_ID_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    record_id: Identifier
    fields: _containers.RepeatedCompositeFieldContainer[RecordField]
    def __init__(self, record_id: _Optional[_Union[Identifier, _Mapping]] = ..., fields: _Optional[_Iterable[_Union[RecordField, _Mapping]]] = ...) -> None: ...

class RecordField(_message.Message):
    __slots__ = ("label", "value")
    LABEL_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    label: str
    value: Value
    def __init__(self, label: _Optional[str] = ..., value: _Optional[_Union[Value, _Mapping]] = ...) -> None: ...

class Identifier(_message.Message):
    __slots__ = ("package_id", "module_name", "entity_name")
    PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    MODULE_NAME_FIELD_NUMBER: _ClassVar[int]
    ENTITY_NAME_FIELD_NUMBER: _ClassVar[int]
    package_id: str
    module_name: str
    entity_name: str
    def __init__(self, package_id: _Optional[str] = ..., module_name: _Optional[str] = ..., entity_name: _Optional[str] = ...) -> None: ...

class Variant(_message.Message):
    __slots__ = ("variant_id", "constructor", "value")
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    CONSTRUCTOR_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    variant_id: Identifier
    constructor: str
    value: Value
    def __init__(self, variant_id: _Optional[_Union[Identifier, _Mapping]] = ..., constructor: _Optional[str] = ..., value: _Optional[_Union[Value, _Mapping]] = ...) -> None: ...

class Enum(_message.Message):
    __slots__ = ("enum_id", "constructor")
    ENUM_ID_FIELD_NUMBER: _ClassVar[int]
    CONSTRUCTOR_FIELD_NUMBER: _ClassVar[int]
    enum_id: Identifier
    constructor: str
    def __init__(self, enum_id: _Optional[_Union[Identifier, _Mapping]] = ..., constructor: _Optional[str] = ...) -> None: ...

class List(_message.Message):
    __slots__ = ("elements",)
    ELEMENTS_FIELD_NUMBER: _ClassVar[int]
    elements: _containers.RepeatedCompositeFieldContainer[Value]
    def __init__(self, elements: _Optional[_Iterable[_Union[Value, _Mapping]]] = ...) -> None: ...

class Optional(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: Value
    def __init__(self, value: _Optional[_Union[Value, _Mapping]] = ...) -> None: ...

class TextMap(_message.Message):
    __slots__ = ("entries",)
    class Entry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: Value
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Value, _Mapping]] = ...) -> None: ...
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[TextMap.Entry]
    def __init__(self, entries: _Optional[_Iterable[_Union[TextMap.Entry, _Mapping]]] = ...) -> None: ...

class GenMap(_message.Message):
    __slots__ = ("entries",)
    class Entry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: Value
        value: Value
        def __init__(self, key: _Optional[_Union[Value, _Mapping]] = ..., value: _Optional[_Union[Value, _Mapping]] = ...) -> None: ...
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[GenMap.Entry]
    def __init__(self, entries: _Optional[_Iterable[_Union[GenMap.Entry, _Mapping]]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .sequencer_bft_administration_service_pb2 import AddPeerEndpointRequest, AddPeerEndpointResponse, GetOrderingTopologyRequest, GetOrderingTopologyResponse, GetPeerNetworkStatusRequest, GetPeerNetworkStatusResponse, RemovePeerEndpointRequest, RemovePeerEndpointResponse

__all__ = [
    "SequencerBftAdministrationServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class SequencerBftAdministrationServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _SequencerBftAdministrationServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _SequencerBftAdministrationServiceAsyncStub: ...  # type: ignore
    def AddPeerEndpoint(self, __1: AddPeerEndpointRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[AddPeerEndpointResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, AddPeerEndpointResponse]]: ...
    def RemovePeerEndpoint(self, __1: RemovePeerEndpointRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[RemovePeerEndpointResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, RemovePeerEndpointResponse]]: ...
    def GetPeerNetworkStatus(self, __1: GetPeerNetworkStatusRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetPeerNetworkStatusResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetPeerNetworkStatusResponse]]: ...
    def GetOrderingTopology(self, __1: GetOrderingTopologyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetOrderingTopologyResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetOrderingTopologyResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerBftAdministrationServiceBlockingStub(SequencerBftAdministrationServiceStub):
    def AddPeerEndpoint(self, __1: AddPeerEndpointRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AddPeerEndpointResponse: ...
    def RemovePeerEndpoint(self, __1: RemovePeerEndpointRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RemovePeerEndpointResponse: ...
    def GetPeerNetworkStatus(self, __1: GetPeerNetworkStatusRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetPeerNetworkStatusResponse: ...
    def GetOrderingTopology(self, __1: GetOrderingTopologyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetOrderingTopologyResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerBftAdministrationServiceAsyncStub(SequencerBftAdministrationServiceStub):
    def AddPeerEndpoint(self, __1: AddPeerEndpointRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, AddPeerEndpointResponse]: ...  # type: ignore
    def RemovePeerEndpoint(self, __1: RemovePeerEndpointRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, RemovePeerEndpointResponse]: ...  # type: ignore
    def GetPeerNetworkStatus(self, __1: GetPeerNetworkStatusRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetPeerNetworkStatusResponse]: ...  # type: ignore
    def GetOrderingTopology(self, __1: GetOrderingTopologyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetOrderingTopologyResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v0 import crypto_pb2 as _crypto_pb2
from ..v0 import common_pb2 as _common_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SerializableContract(_message.Message):
    __slots__ = ("contract_id", "raw_contract_instance", "metadata", "ledger_create_time", "contract_salt")
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    RAW_CONTRACT_INSTANCE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    LEDGER_CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_SALT_FIELD_NUMBER: _ClassVar[int]
    contract_id: str
    raw_contract_instance: bytes
    metadata: _common_pb2.SerializableContract.Metadata
    ledger_create_time: _timestamp_pb2.Timestamp
    contract_salt: _crypto_pb2.Salt
    def __init__(self, contract_id: _Optional[str] = ..., raw_contract_instance: _Optional[bytes] = ..., metadata: _Optional[_Union[_common_pb2.SerializableContract.Metadata, _Mapping]] = ..., ledger_create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., contract_salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ...) -> None: ...

class GlobalKey(_message.Message):
    __slots__ = ("template_id", "key", "package_name")
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    template_id: bytes
    key: bytes
    package_name: str
    def __init__(self, template_id: _Optional[bytes] = ..., key: _Optional[bytes] = ..., package_name: _Optional[str] = ...) -> None: ...

class Metadata(_message.Message):
    __slots__ = ("non_maintainer_signatories", "non_signatory_stakeholders", "key", "maintainers")
    NON_MAINTAINER_SIGNATORIES_FIELD_NUMBER: _ClassVar[int]
    NON_SIGNATORY_STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    MAINTAINERS_FIELD_NUMBER: _ClassVar[int]
    non_maintainer_signatories: _containers.RepeatedScalarFieldContainer[str]
    non_signatory_stakeholders: _containers.RepeatedScalarFieldContainer[str]
    key: GlobalKey
    maintainers: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, non_maintainer_signatories: _Optional[_Iterable[str]] = ..., non_signatory_stakeholders: _Optional[_Iterable[str]] = ..., key: _Optional[_Union[GlobalKey, _Mapping]] = ..., maintainers: _Optional[_Iterable[str]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v1/commands.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v1/commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%com/daml/ledger/api/v1/commands.proto\x12\x16\x63om.daml.ledger.api.v1\x1a\"com/daml/ledger/api/v1/value.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xeb\x06\n\x08\x43ommands\x12\x1b\n\tledger_id\x18\x01 \x01(\tR\x08ledgerId\x12\x1f\n\x0bworkflow_id\x18\x02 \x01(\tR\nworkflowId\x12%\n\x0e\x61pplication_id\x18\x03 \x01(\tR\rapplicationId\x12\x1d\n\ncommand_id\x18\x04 \x01(\tR\tcommandId\x12\x14\n\x05party\x18\x05 \x01(\tR\x05party\x12;\n\x08\x63ommands\x18\x08 \x03(\x0b\x32\x1f.com.daml.ledger.api.v1.CommandR\x08\x63ommands\x12N\n\x12\x64\x65\x64uplication_time\x18\t \x01(\x0b\x32\x19.google.protobuf.DurationB\x02\x18\x01H\x00R\x11\x64\x65\x64uplicationTime\x12R\n\x16\x64\x65\x64uplication_duration\x18\x0f \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x15\x64\x65\x64uplicationDuration\x12\x33\n\x14\x64\x65\x64uplication_offset\x18\x10 \x01(\tH\x00R\x13\x64\x65\x64uplicationOffset\x12I\n\x13min_ledger_time_abs\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10minLedgerTimeAbs\x12H\n\x13min_ledger_time_rel\x18\x0b \x01(\x0b\x32\x19.google.protobuf.DurationR\x10minLedgerTimeRel\x12\x15\n\x06\x61\x63t_as\x18\x0c \x03(\tR\x05\x61\x63tAs\x12\x17\n\x07read_as\x18\r \x03(\tR\x06readAs\x12#\n\rsubmission_id\x18\x0e \x01(\tR\x0csubmissionId\x12Z\n\x13\x64isclosed_contracts\x18\x11 \x03(\x0b\x32).com.daml.ledger.api.v1.DisclosedContractR\x12\x64isclosedContracts\x12\x45\n\x1fpackage_id_selection_preference\x18\x12 \x03(\tR\x1cpackageIdSelectionPreferenceB\x16\n\x14\x64\x65\x64uplication_periodJ\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08\"\xd4\x02\n\x07\x43ommand\x12?\n\x06\x63reate\x18\x01 \x01(\x0b\x32%.com.daml.ledger.api.v1.CreateCommandH\x00R\x06\x63reate\x12\x45\n\x08\x65xercise\x18\x02 \x01(\x0b\x32\'.com.daml.ledger.api.v1.ExerciseCommandH\x00R\x08\x65xercise\x12T\n\rexerciseByKey\x18\x04 \x01(\x0b\x32,.com.daml.ledger.api.v1.ExerciseByKeyCommandH\x00R\rexerciseByKey\x12`\n\x11\x63reateAndExercise\x18\x03 \x01(\x0b\x32\x30.com.daml.ledger.api.v1.CreateAndExerciseCommandH\x00R\x11\x63reateAndExerciseB\t\n\x07\x63ommand\"\x9f\x01\n\rCreateCommand\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\ntemplateId\x12I\n\x10\x63reate_arguments\x18\x02 \x01(\x0b\x32\x1e.com.daml.ledger.api.v1.RecordR\x0f\x63reateArguments\"\xd7\x01\n\x0f\x45xerciseCommand\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\ntemplateId\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12\x16\n\x06\x63hoice\x18\x03 \x01(\tR\x06\x63hoice\x12\x46\n\x0f\x63hoice_argument\x18\x04 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x0e\x63hoiceArgument\"\xfd\x01\n\x14\x45xerciseByKeyCommand\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\ntemplateId\x12@\n\x0c\x63ontract_key\x18\x02 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x0b\x63ontractKey\x12\x16\n\x06\x63hoice\x18\x03 \x01(\tR\x06\x63hoice\x12\x46\n\x0f\x63hoice_argument\x18\x04 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x0e\x63hoiceArgument\"\x8a\x02\n\x18\x43reateAndExerciseCommand\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\ntemplateId\x12I\n\x10\x63reate_arguments\x18\x02 \x01(\x0b\x32\x1e.com.daml.ledger.api.v1.RecordR\x0f\x63reateArguments\x12\x16\n\x06\x63hoice\x18\x03 \x01(\tR\x06\x63hoice\x12\x46\n\x0f\x63hoice_argument\x18\x04 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x0e\x63hoiceArgument\"\xb9\x01\n\x11\x44isclosedContract\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\ntemplateId\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12,\n\x12\x63reated_event_blob\x18\x06 \x01(\x0cR\x10\x63reatedEventBlobJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\x42\x8c\x01\n\x16\x63om.daml.ledger.api.v1B\x12\x43ommandsOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v1.commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v1B\022CommandsOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1'
  _globals['_COMMANDS'].fields_by_name['deduplication_time']._loaded_options = None
  _globals['_COMMANDS'].fields_by_name['deduplication_time']._serialized_options = b'\030\001'
  _globals['_COMMANDS']._serialized_start=167
  _globals['_COMMANDS']._serialized_end=1042
  _globals['_COMMAND']._serialized_start=1045
  _globals['_COMMAND']._serialized_end=1385
  _globals['_CREATECOMMAND']._serialized_start=1388
  _globals['_CREATECOMMAND']._serialized_end=1547
  _globals['_EXERCISECOMMAND']._serialized_start=1550
  _globals['_EXERCISECOMMAND']._serialized_end=1765
  _globals['_EXERCISEBYKEYCOMMAND']._serialized_start=1768
  _globals['_EXERCISEBYKEYCOMMAND']._serialized_end=2021
  _globals['_CREATEANDEXERCISECOMMAND']._serialized_start=2024
  _globals['_CREATEANDEXERCISECOMMAND']._serialized_end=2290
  _globals['_DISCLOSEDCONTRACT']._serialized_start=2293
  _globals['_DISCLOSEDCONTRACT']._serialized_end=2478
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import event_pb2 as _event_pb2
from . import value_pb2 as _value_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetEventsByContractIdRequest(_message.Message):
    __slots__ = ("contract_id", "requesting_parties")
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    REQUESTING_PARTIES_FIELD_NUMBER: _ClassVar[int]
    contract_id: str
    requesting_parties: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, contract_id: _Optional[str] = ..., requesting_parties: _Optional[_Iterable[str]] = ...) -> None: ...

class GetEventsByContractIdResponse(_message.Message):
    __slots__ = ("create_event", "archive_event")
    CREATE_EVENT_FIELD_NUMBER: _ClassVar[int]
    ARCHIVE_EVENT_FIELD_NUMBER: _ClassVar[int]
    create_event: _event_pb2.CreatedEvent
    archive_event: _event_pb2.ArchivedEvent
    def __init__(self, create_event: _Optional[_Union[_event_pb2.CreatedEvent, _Mapping]] = ..., archive_event: _Optional[_Union[_event_pb2.ArchivedEvent, _Mapping]] = ...) -> None: ...

class GetEventsByContractKeyRequest(_message.Message):
    __slots__ = ("contract_key", "template_id", "requesting_parties", "continuation_token")
    CONTRACT_KEY_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    REQUESTING_PARTIES_FIELD_NUMBER: _ClassVar[int]
    CONTINUATION_TOKEN_FIELD_NUMBER: _ClassVar[int]
    contract_key: _value_pb2.Value
    template_id: _value_pb2.Identifier
    requesting_parties: _containers.RepeatedScalarFieldContainer[str]
    continuation_token: str
    def __init__(self, contract_key: _Optional[_Union[_value_pb2.Value, _Mapping]] = ..., template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., requesting_parties: _Optional[_Iterable[str]] = ..., continuation_token: _Optional[str] = ...) -> None: ...

class GetEventsByContractKeyResponse(_message.Message):
    __slots__ = ("create_event", "archive_event", "continuation_token")
    CREATE_EVENT_FIELD_NUMBER: _ClassVar[int]
    ARCHIVE_EVENT_FIELD_NUMBER: _ClassVar[int]
    CONTINUATION_TOKEN_FIELD_NUMBER: _ClassVar[int]
    create_event: _event_pb2.CreatedEvent
    archive_event: _event_pb2.ArchivedEvent
    continuation_token: str
    def __init__(self, create_event: _Optional[_Union[_event_pb2.CreatedEvent, _Mapping]] = ..., archive_event: _Optional[_Union[_event_pb2.ArchivedEvent, _Mapping]] = ..., continuation_token: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/admin/v0/inspection_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/admin/v0/inspection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEcom/digitalasset/canton/participant/admin/v0/inspection_service.proto\x12,com.digitalasset.canton.participant.admin.v0\x1a\x1fgoogle/protobuf/timestamp.proto\"\xff\x01\n\x14LookupContractDomain\x1a*\n\x07Request\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x03(\tR\ncontractId\x1a\xba\x01\n\x08Response\x12r\n\x07results\x18\x01 \x03(\x0b\x32X.com.digitalasset.canton.participant.admin.v0.LookupContractDomain.Response.ResultsEntryR\x07results\x1a:\n\x0cResultsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"t\n\x17LookupTransactionDomain\x1a\x30\n\x07Request\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x1a\'\n\x08Response\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\"}\n\x12LookupOffsetByTime\x1a\x43\n\x07Request\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1a\"\n\x08Response\x12\x16\n\x06offset\x18\x01 \x01(\tR\x06offset\"Z\n\x13LookupOffsetByIndex\x1a\x1f\n\x07Request\x12\x14\n\x05index\x18\x01 \x01(\x03R\x05index\x1a\"\n\x08Response\x12\x16\n\x06offset\x18\x01 \x01(\tR\x06offset\"\xa7\x01\n\rCountInFlight\x1a&\n\x07Request\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x1an\n\x08Response\x12/\n\x13pending_submissions\x18\x01 \x01(\rR\x12pendingSubmissions\x12\x31\n\x14pending_transactions\x18\x02 \x01(\rR\x13pendingTransactions2\xf8\x06\n\x11InspectionService\x12\xaf\x01\n\x14LookupContractDomain\x12J.com.digitalasset.canton.participant.admin.v0.LookupContractDomain.Request\x1aK.com.digitalasset.canton.participant.admin.v0.LookupContractDomain.Response\x12\xb8\x01\n\x17LookupTransactionDomain\x12M.com.digitalasset.canton.participant.admin.v0.LookupTransactionDomain.Request\x1aN.com.digitalasset.canton.participant.admin.v0.LookupTransactionDomain.Response\x12\xa9\x01\n\x12LookupOffsetByTime\x12H.com.digitalasset.canton.participant.admin.v0.LookupOffsetByTime.Request\x1aI.com.digitalasset.canton.participant.admin.v0.LookupOffsetByTime.Response\x12\xac\x01\n\x13LookupOffsetByIndex\x12I.com.digitalasset.canton.participant.admin.v0.LookupOffsetByIndex.Request\x1aJ.com.digitalasset.canton.participant.admin.v0.LookupOffsetByIndex.Response\x12\x9a\x01\n\rCountInFlight\x12\x43.com.digitalasset.canton.participant.admin.v0.CountInFlight.Request\x1a\x44.com.digitalasset.canton.participant.admin.v0.CountInFlight.ResponseB]Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.admin.v0.inspection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0'
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._loaded_options = None
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._serialized_options = b'8\001'
  _globals['_LOOKUPCONTRACTDOMAIN']._serialized_start=153
  _globals['_LOOKUPCONTRACTDOMAIN']._serialized_end=408
  _globals['_LOOKUPCONTRACTDOMAIN_REQUEST']._serialized_start=177
  _globals['_LOOKUPCONTRACTDOMAIN_REQUEST']._serialized_end=219
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE']._serialized_start=222
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE']._serialized_end=408
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._serialized_start=350
  _globals['_LOOKUPCONTRACTDOMAIN_RESPONSE_RESULTSENTRY']._serialized_end=408
  _globals['_LOOKUPTRANSACTIONDOMAIN']._serialized_start=410
  _globals['_LOOKUPTRANSACTIONDOMAIN']._serialized_end=526
  _globals['_LOOKUPTRANSACTIONDOMAIN_REQUEST']._serialized_start=437
  _globals['_LOOKUPTRANSACTIONDOMAIN_REQUEST']._serialized_end=485
  _globals['_LOOKUPTRANSACTIONDOMAIN_RESPONSE']._serialized_start=487
  _globals['_LOOKUPTRANSACTIONDOMAIN_RESPONSE']._serialized_end=526
  _globals['_LOOKUPOFFSETBYTIME']._serialized_start=528
  _globals['_LOOKUPOFFSETBYTIME']._serialized_end=653
  _globals['_LOOKUPOFFSETBYTIME_REQUEST']._serialized_start=550
  _globals['_LOOKUPOFFSETBYTIME_REQUEST']._serialized_end=617
  _globals['_LOOKUPOFFSETBYTIME_RESPONSE']._serialized_start=619
  _globals['_LOOKUPOFFSETBYTIME_RESPONSE']._serialized_end=653
  _globals['_LOOKUPOFFSETBYINDEX']._serialized_start=655
  _globals['_LOOKUPOFFSETBYINDEX']._serialized_end=745
  _globals['_LOOKUPOFFSETBYINDEX_REQUEST']._serialized_start=678
  _globals['_LOOKUPOFFSETBYINDEX_REQUEST']._serialized_end=709
  _globals['_LOOKUPOFFSETBYINDEX_RESPONSE']._serialized_start=619
  _globals['_LOOKUPOFFSETBYINDEX_RESPONSE']._serialized_end=653
  _globals['_COUNTINFLIGHT']._serialized_start=748
  _globals['_COUNTINFLIGHT']._serialized_end=915
  _globals['_COUNTINFLIGHT_REQUEST']._serialized_start=765
  _globals['_COUNTINFLIGHT_REQUEST']._serialized_end=803
  _globals['_COUNTINFLIGHT_RESPONSE']._serialized_start=805
  _globals['_COUNTINFLIGHT_RESPONSE']._serialized_end=915
  _globals['_INSPECTIONSERVICE']._serialized_start=918
  _globals['_INSPECTIONSERVICE']._serialized_end=1806
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from ....admin.pruning.v30 import pruning_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2
from . import sequencer_pruning_administration_service_pb2 as com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__pruning__administration__service__pb2

GRPC_GENERATED_VERSION = '1.67.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in com/digitalasset/canton/sequencer/admin/v30/sequencer_pruning_administration_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SequencerPruningAdministrationServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Prune = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/Prune',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__pruning__administration__service__pb2.SequencerPruning.PruneRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__pruning__administration__service__pb2.SequencerPruning.PruneResponse.FromString,
                _registered_method=True)
        self.SetSchedule = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/SetSchedule',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetSchedule.Request.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetSchedule.Response.FromString,
                _registered_method=True)
        self.SetCron = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/SetCron',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetCron.Request.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetCron.Response.FromString,
                _registered_method=True)
        self.SetMaxDuration = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/SetMaxDuration',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetMaxDuration.Request.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetMaxDuration.Response.FromString,
                _registered_method=True)
        self.SetRetention = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/SetRetention',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetRetention.Request.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetRetention.Response.FromString,
                _registered_method=True)
        self.ClearSchedule = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/ClearSchedule',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ClearSchedule.Request.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ClearSchedule.Response.FromString,
                _registered_method=True)
        self.GetSchedule = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/GetSchedule',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetSchedule.Request.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetSchedule.Response.FromString,
                _registered_method=True)
        self.LocatePruningTimestamp = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/LocatePruningTimestamp',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.LocatePruningTimestamp.Request.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.LocatePruningTimestamp.Response.FromString,
                _registered_method=True)


class SequencerPruningAdministrationServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Prune(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCron(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMaxDuration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRetention(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSchedule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LocatePruningTimestamp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SequencerPruningAdministrationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Prune': grpc.unary_unary_rpc_method_handler(
                    servicer.Prune,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__pruning__administration__service__pb2.SequencerPruning.PruneRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__pruning__administration__service__pb2.SequencerPruning.PruneResponse.SerializeToString,
            ),
            'SetSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSchedule,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetSchedule.Request.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetSchedule.Response.SerializeToString,
            ),
            'SetCron': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCron,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetCron.Request.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetCron.Response.SerializeToString,
            ),
            'SetMaxDuration': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMaxDuration,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetMaxDuration.Request.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetMaxDuration.Response.SerializeToString,
            ),
            'SetRetention': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRetention,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetRetention.Request.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetRetention.Response.SerializeToString,
            ),
            'ClearSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearSchedule,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ClearSchedule.Request.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ClearSchedule.Response.SerializeToString,
            ),
            'GetSchedule': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSchedule,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetSchedule.Request.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetSchedule.Response.SerializeToString,
            ),
            'LocatePruningTimestamp': grpc.unary_unary_rpc_method_handler(
                    servicer.LocatePruningTimestamp,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.LocatePruningTimestamp.Request.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.LocatePruningTimestamp.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SequencerPruningAdministrationService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Prune(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/Prune',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__pruning__administration__service__pb2.SequencerPruning.PruneRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__pruning__administration__service__pb2.SequencerPruning.PruneResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/SetSchedule',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetSchedule.Request.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetSchedule.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetCron(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/SetCron',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetCron.Request.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetCron.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetMaxDuration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/SetMaxDuration',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetMaxDuration.Request.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetMaxDuration.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetRetention(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/SetRetention',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetRetention.Request.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.SetRetention.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClearSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/ClearSchedule',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ClearSchedule.Request.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.ClearSchedule.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSchedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/GetSchedule',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetSchedule.Request.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.GetSchedule.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LocatePruningTimestamp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.admin.v30.SequencerPruningAdministrationService/LocatePruningTimestamp',
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.LocatePruningTimestamp.Request.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2.LocatePruningTimestamp.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import logging

__all__ = ["Formatter", "initialize"]

grey = "\x1b[38;20m"
yellow = "\x1b[33;20m"
red = "\x1b[31;20m"
bold_red = "\x1b[31;1m"
reset = "\x1b[0m"
format = "%(asctime)s.%(msecs)03d %(levelname)s (%(filename)s:%(lineno)d) %(message)s "


class Formatter(logging.Formatter):
    FORMATS = {
        logging.DEBUG: grey + format + reset,
        logging.INFO: grey + format + reset,
        logging.WARNING: yellow + format + reset,
        logging.ERROR: red + format + reset,
        logging.CRITICAL: bold_red + format + reset,
    }

    def format(self, record):
        log_fmt = self.FORMATS.get(record.levelno)
        formatter = logging.Formatter(log_fmt, datefmt=self.datefmt)
        return formatter.format(record)


def initialize(log_level: str) -> logging.Logger:
    numeric_level = getattr(logging, log_level.upper(), None)
    if not isinstance(numeric_level, int):
        raise ValueError("Invalid log level: %s" % log_level)

    logger = logging.getLogger("_dazl")
    logger.setLevel(log_level.upper())

    ch = logging.StreamHandler()
    ch.setLevel(logging.DEBUG)

    # this is not a long-running process, so save space and only output the time without the date
    ch.setFormatter(Formatter(datefmt="%H:%M:%S"))

    logger.addHandler(ch)
    return logger
